@@ -14,8 +14,8 @@ def main():
     builder.run(argv)
   except FileNotFoundError as e:
     print(f'cannot open file "{e.filename}"')
-  except Exception as e:
-    print(f'unhandled exception have been occurred:\n\nmsg: {e.args}')
+  #except Exception as e:
+  #  print(f'unhandled exception have been occurred:\n\nmsg: {e.args}')
 
 # ------
 
